@@ -7,6 +7,7 @@ from ._base import DetectionParser
 from ._coco import *
 from ._dollar import *
 from ._erti import *
+from ._mot import *
 from ._pascalvoc import *
 from ._yaml import *
 
@@ -15,6 +16,7 @@ detection_formats = {
     'coco': CocoParser,
     'dollar': DollarParser,
     'erti': ErtiParser,
+    'mot': MotParser,
     'pascalvoc': PascalVocParser,
     'yaml': YamlParser,
 }
