@@ -10,25 +10,31 @@ __all__ = ['LogAggregator']
 
 
 class LogAggregator:
-    def __init__(self, msg=None):
-        self.logger = logging.getLogger('brambox')
+    def __init__(self, msg=None, loggername='brambox'):
+        self.logger = logging.getLogger(loggername)
         self.msg = msg
         self.set = set()
 
     def __enter__(self):
-        for handler in self.logger.handlers:
-            handler.addFilter(self)
+        logger = self.logger
+        while logger is not None:
+            for handler in logger.handlers:
+                handler.addFilter(self)
+            logger = logger.parent
 
     def __exit__(self, type, value, traceback):
-        for handler in self.logger.handlers:
-            handler.removeFilter(self)
+        logger = self.logger
+        while logger is not None:
+            for handler in logger.handlers:
+                handler.removeFilter(self)
+            logger = logger.parent
 
     def filter(self, record):
-        info = (record.levelno, record.getMessage())
+        info = (record.name, record.levelno, record.getMessage())
         if info in self.set:
             return False
         else:
             self.set.add(info)
             if self.msg is not None:
                 record.msg = self.msg.format(record.msg)
-                return True
+            return True
